Stan Math Library: stan/math/fwd/scal/fun/digamma.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

digamma.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_DIGAMMA_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_DIGAMMA_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/digamma.hpp>
7 #include <stan/math/prim/scal/fun/trigamma.hpp>
8
9 namespace stan {
10
11 namespace math {
12
13 template <typename T>
14 inline
15 fvar<T>
16 digamma(const fvar<T>& x) {
17 using stan::math::digamma;
18 using stan::math::trigamma;
19 return fvar<T>(digamma(x.val_), x.d_ * trigamma(x.val_));
20 }
21 }
22 }
23 #endif
stan::math::trigamma
T trigamma(T x)
Definition: trigamma.hpp:50
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
trigamma.hpp
stan::math::fvar
Definition: fvar.hpp:13
stan::math::digamma
fvar< T > digamma(const fvar< T > &x)
Definition: digamma.hpp:16

[ Stan Home Page ] © 2011–2016, Stan Development Team.